@@ -1,13 +1,13 @@
 /*  
  *  EDIT THIS FILE WITH CAUTION  (cgi-fsm.c)
  *  
- *  It has been AutoGen-ed  Sunday October 13, 2002 at 12:22:46 PM PDT
+ *  It has been AutoGen-ed  Sunday February 16, 2003 at 12:05:33 PM PST
  *  From the definitions    cgi.def
  *  and the template file   fsm
  *
  *  Automated Finite State Machine
  *
- *  Copyright (c) 2001-2002  by  Bruce Korb
+ *  Copyright (c) 2001-2003  by  Bruce Korb
  *
  *  AutoFSM is free software copyrighted by Bruce Korb.
  *  
@@ -180,10 +180,10 @@ int
 cgi_invalid_transition( te_cgi_state st, te_cgi_event evt )
 {
     /* START == INVALID TRANS MSG == DO NOT CHANGE THIS COMMENT */
-    char* pz = asprintf( zFsmErr, st, CGI_STATE_NAME( st ),
-						 evt, CGI_EVT_NAME( evt ));
-	pz = asprintf( "CGI parsing error:  %s", pz );
-    AG_ABEND( pz );
+    char* pz = aprf( zFsmErr, st, CGI_STATE_NAME( st ),
+                     evt, CGI_EVT_NAME( evt ));
+
+    AG_ABEND( aprf( "CGI parsing error:  %s", pz ));
     /* END   == INVALID TRANS MSG == DO NOT CHANGE THIS COMMENT */
 
     return EXIT_FAILURE;
@@ -288,7 +288,7 @@ cgi_run_fsm(
 
             z[0] = *(pzSrc++);
             z[1] = *(pzSrc++);
-            z[2] = '\0';
+            z[2] = NUL;
             inlen -= 2;
 
             switch (*(pzOut++) = (int)strtol( z, NULL, 16 )) {
