@@ -1,12 +1,12 @@
 /*
- *  $Id: defLoad.c,v 1.21 2002/05/29 02:32:39 bkorb Exp $
+ *  $Id: defLoad.c,v 1.24 2003/02/15 22:58:59 bkorb Exp $
  *  This module loads the definitions, calls yyparse to decipher them,
  *  and then makes a fixup pass to point all children definitions to
  *  their parent definition.
  */
 
 /*
- *  AutoGen copyright 1992-2002 Bruce Korb
+ *  AutoGen copyright 1992-2003 Bruce Korb
  *
  *  AutoGen is free software.
  *  You may redistribute it and/or modify it under the terms of the
@@ -41,8 +41,8 @@ compareIndex( const void* p1, const void* p2 )
     tDefEntry* pE2 = *((tDefEntry**)p2);
     int  res = pE1->index - pE2->index;
     if (res == 0)
-        AG_ABEND( asprintf( "two %s definitions have index %ld\n",
-                            pE1->pzDefName, pE1->index ));
+        AG_ABEND( aprf( "two %s definitions have index %ld\n", pE1->pzDefName,
+                        pE1->index ));
 
     return res;
 }
@@ -328,13 +328,13 @@ readDefines( void )
         char* pz;
         struct stat stbf;
         if (stat( OPT_ARG( DEFINITIONS ), &stbf ) != 0)
-            AG_ABEND( asprintf( zCannot, errno, "stat",
-                                OPT_ARG( DEFINITIONS ), strerror( errno )));
+            AG_ABEND( aprf( zCannot, errno, "stat", OPT_ARG( DEFINITIONS ),
+                            strerror( errno )));
 
         if (! S_ISREG( stbf.st_mode )) {
             errno = EINVAL;
-            AG_ABEND( asprintf( zCannot, errno, "open non-regular file",
-                                OPT_ARG( DEFINITIONS ), strerror( errno )));
+            AG_ABEND( aprf( zCannot, errno, "open non-regular file",
+                            OPT_ARG( DEFINITIONS ), strerror( errno )));
         }
 
         /*
@@ -378,8 +378,8 @@ readDefines( void )
     fp = useStdin ? stdin
                   : fopen( OPT_ARG( DEFINITIONS ), "r" FOPEN_TEXT_FLAG );
     if (fp == NULL)
-        AG_ABEND( asprintf( zCannot, errno, "open",
-                            OPT_ARG( DEFINITIONS ), strerror( errno )));
+        AG_ABEND( aprf( zCannot, errno, "open", OPT_ARG( DEFINITIONS ),
+                        strerror( errno )));
 
     /*
      *  Read until done...
@@ -398,8 +398,8 @@ readDefines( void )
             if (feof( fp ) || useStdin)
                 break;
 
-            AG_ABEND( asprintf( zCannot, errno, "read",
-                                OPT_ARG( DEFINITIONS ), strerror( errno )));
+            AG_ABEND( aprf( zCannot, errno, "read", OPT_ARG( DEFINITIONS ),
+                            strerror( errno )));
         }
 
         /*
