@@ -1,12 +1,12 @@
 
 /*
- *  $Id: funcDef.c,v 1.48 2002/09/30 03:12:51 bkorb Exp $
+ *  $Id: funcDef.c,v 1.52 2003/02/15 22:58:59 bkorb Exp $
  *
  *  This module implements the DEFINE text function.
  */
 
 /*
- *  AutoGen copyright 1992-2002 Bruce Korb
+ *  AutoGen copyright 1992-2003 Bruce Korb
  *
  *  AutoGen is free software.
  *  You may redistribute it and/or modify it under the terms of the
@@ -630,9 +630,9 @@ mFunc_Invoke( tTemplate* pT, tMacro* pMac )
                 pT->pzTemplText + pMac->ozName );
 
             if (pMac->funcPrivate == NULL) {
-                pzText = asprintf( zNoResolution,
-                                   pT->pzTemplText + pMac->ozName );
+                pzText = aprf( zNoResolution, pT->pzTemplText + pMac->ozName );
                 AG_ABEND_IN( pT, pMac, pzText );
+                /* NOTREACHED */
             }
 
             return mFunc_Define( pT, pMac );
@@ -647,9 +647,9 @@ mFunc_Invoke( tTemplate* pT, tMacro* pMac )
 
     pInv = findTemplate( ag_scm2zchars( macName, "macro name" ));
     if (pInv == NULL) {
-        pzText = asprintf( zNoResolution,
-                           ag_scm2zchars( macName, "macro name" ));
+        pzText = aprf( zNoResolution, ag_scm2zchars( macName, "macro name" ));
         AG_ABEND_IN( pT, pMac, pzText );
+        /* NOTREACHED */
     }
 
     pMac->funcPrivate = (void*)pInv;
