@@ -1,12 +1,12 @@
 
 /*
- *  $Id: funcFor.c,v 1.30 2002/09/20 04:56:45 bkorb Exp $
+ *  $Id: funcFor.c,v 1.35 2003/02/15 22:58:59 bkorb Exp $
  *
- *  This module implements the FOR text function.
+ *  This module implements the FOR text macro.
  */
 
 /*
- *  AutoGen copyright 1992-2002 Bruce Korb
+ *  AutoGen copyright 1992-2003 Bruce Korb
  *
  *  AutoGen is free software.
  *  You may redistribute it and/or modify it under the terms of the
@@ -493,6 +493,108 @@ doForEach( tTemplate*   pT,
 
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 
+tSCC zNoEnd[] = "%s ERROR:  FOR loop `%s' does not end\n";
+
+STATIC void
+load_ForIn( tCC* pzSrc, int srcLen, tTemplate* pT, tMacro* pMac )
+{
+    char* pzName = pT->pzTemplText + pMac->ozName;
+    int   ix     = 0;
+    char* pz;
+    tDefEntry*  pPrev = NULL;
+
+    /*
+     *  Find the first text value
+     */
+    pzSrc  += 2;
+    srcLen -= 3;
+    while (isspace( *++pzSrc ))  srcLen--;
+    if (*pzSrc == NUL)
+        AG_ABEND_IN( pT, pMac, "FOR x IN ... has no list" );
+
+    {
+        size_t nmlen = strlen( pzName );
+
+        pz = AGALOC( srcLen + 2 + nmlen, "copy of FOR x IN ... text" );
+        strcpy( pz, pzName );
+        pzName = pz;
+        pz += nmlen + 1;
+    }
+
+    memcpy( pz, pzSrc, srcLen );
+    pz[ srcLen ] = NUL;
+
+    do  {
+        tDefEntry* pDef = getEntry();
+        int foundComma  = 0;
+
+        pDef->pzDefName = pzName;
+        pDef->index     = ix++;
+        pDef->valType   = VALTYP_TEXT;
+        pDef->pzValue   = pz;
+
+        switch (*pz) {
+        case '\'':
+        case '"':
+            pz = spanQuote( pz );
+            /*
+             *  Clean up trailing commas
+             */
+            while (isspace( *pz ))  pz++;
+            if (*pz == ',')
+                pz++;
+            break;
+
+        default:
+            for (;;) {
+                char ch = *(pz++);
+                switch (ch) {
+                case ' ': case '\t': case '\f': case '\v': case '\n':
+                    pz[-1] = NUL;
+                    if (*pz != ',')
+                        break;
+                    pz++;
+                    /* FALLTHROUGH */
+
+                case ',':
+                    pz[-1] = NUL;
+                    break;
+
+                case NUL:
+                    pz--;
+                    break;
+
+                default:
+                    continue;
+                }
+                break;
+            }
+            break;
+        }
+
+        /*
+         *  Clean up trailing white space
+         */
+        while (isspace( *pz ))  pz++;
+
+        /*
+         *  IF there is a previous entry, link its twin to this one.
+         *  OTHERWISE, it is the head of the twin list.
+         *  Link to funcPrivate.
+         */
+        if (pPrev != NULL)
+            pPrev->pTwin = pDef;
+        else
+            pMac->funcPrivate = pDef;
+
+        pPrev = pDef;
+    } while (*pz != NUL);
+
+    pMac->ozText = 0;
+}
+
+/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
+
 /*=macfunc FOR
  *
  *  what:    Emit a template block multiple times
@@ -509,29 +611,41 @@ doForEach( tTemplate*   pT,
  *  @example
  *  FOR <value-name> (...Scheme expression list
  *  @end example
+ *  or
+ *  @example
+ *  FOR <value-name> IN "quoted string" unquoted-string ...
+ *  @end example
  *
- *  The first argument must be the name of an AutoGen value.  If there is
- *  no value associated with the name, the FOR loop block is skipped
- *  entirely.  The scope of the @code{FOR} function extends to the
- *  corresponding ENDFOR macro.
+ *  Other than for the last form, the first macro argument must be the name of
+ *  an AutoGen value.  If there is no value associated with the name, the
+ *  @code{FOR} template block is skipped entirely.  The scope of the @code{FOR}
+ *  macro extends to the corresponding @code{ENDFOR} macro.  The last form will
+ *  create an array of string values named @code{<value-name>} that only exists
+ *  within the context of this @code{FOR} loop.  With this form, in order to
+ *  use a @code{separator-string}, you must code it into the end of the
+ *  template block using the @code{(last-for?)} predicate function
+ *  (@pxref{SCM last-for?}).
  *
- *  If there are any further arguments, if the first character is either
- *  a semi-colon (@code{;}) or an opening parenthesis (@code{(}), then
- *  it is presumed to be a Scheme expression containing the FOR macro
- *  specific functions @code{for-from}, @code{for-by}, @code{for-to},
- *  and/or @code{for-sep}.  @xref{AutoGen Functions}.  Otherwise, the
- *  remaining text is presumed to be a string for inserting between
- *  each iteration of the loop.  This string will be emitted one time
- *  less than the number of iterations of the loop.  That is, it is
- *  emitted after each loop, excepting for the last iteration.
+ *  If there are any arguments after the @code{value-name}, the initial
+ *  characters are used to determine the form.  If the first character is
+ *  either a semi-colon (@code{;}) or an opening parenthesis (@code{(}), then
+ *  it is presumed to be a Scheme expression containing the FOR macro specific
+ *  functions @code{for-from}, @code{for-by}, @code{for-to}, and/or
+ *  @code{for-sep}.  @xref{AutoGen Functions}.  If it consists of an '@code{i}'
+ *  an '@code{n}' and separated by white space from more text, then the
+ *  @code{FOR x IN} form is processed.  Otherwise, the remaining text is
+ *  presumed to be a string for inserting between each iteration of the loop.
+ *  This string will be emitted one time less than the number of iterations of
+ *  the loop.  That is, it is emitted after each loop, excepting for the last
+ *  iteration.
  *
- *  If the from/by/to functions are invoked, they will specify which
- *  copies of the named value are to be processed.  If there is no
- *  copy of the named value associated with a particular index,
- *  the @code{FOR} template block will be instantiated anyway.
- *  The template must use methods for detecting missing definitions and
- *  emitting default text.  In this fashion, you can insert entries
- *  from a sparse or non-zero based array into a dense, zero based array.
+ *  If the from/by/to functions are invoked, they will specify which copies of
+ *  the named value are to be processed.  If there is no copy of the named
+ *  value associated with a particular index, the @code{FOR} template block
+ *  will be instantiated anyway.  The template must use methods for detecting
+ *  missing definitions and emitting default text.  In this fashion, you can
+ *  insert entries from a sparse or non-zero based array into a dense, zero
+ *  based array.
  *
  *  @strong{NB:} the @code{for-from}, @code{for-to}, @code{for-by} and
  *  @code{for-sep} functions are disabled outside of the context of the
@@ -576,17 +690,21 @@ mFunc_For( tTemplate* pT, tMacro* pMac )
     tDefEntry*  pDef;
     int         loopCt;
 
-    pDef = findDefEntry( pT->pzTemplText + pMac->ozName, &isIndexed );
-    if (pDef == NULL) {
-        if (OPT_VALUE_TRACE >= TRACE_BLOCK_MACROS) {
-            fprintf( pfTrace, "FOR loop skipped - no definition for `%s'\n",
-                     pT->pzTemplText + pMac->ozName );
+    if (pMac->funcPrivate != NULL)
+        pDef = pMac->funcPrivate;
+    else {
+        pDef = findDefEntry( pT->pzTemplText + pMac->ozName, &isIndexed );
+        if (pDef == NULL) {
+            if (OPT_VALUE_TRACE >= TRACE_BLOCK_MACROS) {
+                fprintf( pfTrace, "FOR loop skipped - no definition for `%s'\n",
+                         pT->pzTemplText + pMac->ozName );
 
-            if (OPT_VALUE_TRACE < TRACE_EVERYTHING)
-                fprintf( pfTrace, zFileLine, pT->pzFileName, pMac->lineNo );
+                if (OPT_VALUE_TRACE < TRACE_EVERYTHING)
+                    fprintf( pfTrace, zFileLine, pT->pzFileName, pMac->lineNo );
+            }
+
+            return pMRet;
         }
-
-        return pMRet;
     }
 
     if (++(forInfo.fi_depth) > forInfo.fi_alloc) {
@@ -639,15 +757,13 @@ mFunc_For( tTemplate* pT, tMacro* pMac )
 
 #endif /* DEFINE_LOAD_FUNCTIONS defined */
 
-tSCC zNoEnd[] = "%s ERROR:  FOR loop `%s' does not end\n";
-
     tMacro*
 mLoad_For( tTemplate* pT, tMacro* pMac, tCC** ppzScan )
 {
-    char*        pzCopy = pT->pNext; /* next text dest   */
-    const char*  pzSrc  = (const char*)pMac->ozText; /* macro text */
-    int          srcLen = (int)pMac->res;            /* macro len  */
-    tMacro*      pEndMac;
+    char*   pzCopy = pT->pNext; /* next text dest   */
+    tCC*    pzSrc  = (const char*)pMac->ozText; /* macro text */
+    int     srcLen = (int)pMac->res;            /* macro len  */
+    tMacro* pEndMac;
 
     /*
      *  Save the global macro loading mode
@@ -685,25 +801,43 @@ mLoad_For( tTemplate* pT, tMacro* pMac, tCC** ppzScan )
     }
 
     while (ISNAMECHAR( *pzSrc )) *(pzCopy++) = *(pzSrc++);
-    *(pzCopy++) = '\0';
+    *(pzCopy++) = NUL;
 
-    if (pT->pzTemplText[ pMac->ozName ] == '\0')
+    if (pT->pzTemplText[ pMac->ozName ] == NUL)
         AG_ABEND_IN( pT, pMac, "invalid FOR loop variable" );
 
     /*
-     *  Copy the rest of the macro text into the "text" string
+     *  Skip space to the start of the text following the iterator name
      */
     while (isspace( *pzSrc )) pzSrc++;
     srcLen -= pzSrc - (char*)pMac->ozText;
-    if (srcLen <= 0)
+
+    /*
+     *  No source -> zero offset to text
+     */
+    if (srcLen <= 0) {
         pMac->ozText = 0;
+    }
+
+    /*
+     *  FOR foo IN ...  -> no text, but we create an array of text values
+     */
+    else if (   (strneqvcmp( pzSrc, "in", 2 ) == 0)
+             && isspace( pzSrc[2] )) {
+        load_ForIn( pzSrc, srcLen, pT, pMac );
+    }
+
+    /*
+     *  *EITHER* a:  FOR foo "<<separator>>"
+     *  *OR*         FOR foo (scheme ...) ...
+     */
     else {
         char* pzCopied = pzCopy;
         pMac->ozText = pzCopy - pT->pzTemplText;
         do  {
             *(pzCopy++) = *(pzSrc++);
         } while (--srcLen > 0);
-        *(pzCopy++) = '\0';
+        *(pzCopy++) = NUL;
         if ((*pzCopied == '"') || (*pzCopied == '\''))
             spanQuote( pzCopied );
     }
