@@ -1,12 +1,12 @@
 
 /*
- *  $Id: loadPseudo.c,v 1.20 2002/07/27 18:57:08 bkorb Exp $
+ *  $Id: loadPseudo.c,v 1.24 2003/02/15 22:58:59 bkorb Exp $
  *
  *  This module processes the "pseudo" macro
  */
 
 /*
- *  AutoGen copyright 1992-2002 Bruce Korb
+ *  AutoGen copyright 1992-2003 Bruce Korb
  *
  *  AutoGen is free software.
  *  You may redistribute it and/or modify it under the terms of the
@@ -61,7 +61,7 @@ doSchemeExpr( tCC* pzData, tCC* pzFileName, int lineNo )
     pzEnd = (char*)skipScheme( pzData, pzEnd );
     ch = *pzEnd;
     *pzEnd = NUL;
-    gh_eval_str( pzData );
+    gh_eval_str( (char*)pzData );
     *pzEnd = ch;
     while (pzData < pzEnd)
         if (*(pzData++) == '\n')
@@ -305,7 +305,7 @@ loadPseudoMacro( tCC* pzData, tCC* pzFileName )
     tSCC zMarkErr[] = "start/end macro mark too long";
     tSCC zBadMark[] = "bad template marker in %s on line %d:\n\t%s";
 #   define BAD_MARKER( t ) \
-            AG_ABEND( asprintf( zBadMark, pzFileName, templLineNo, t ))
+            AG_ABEND( aprf( zBadMark, pzFileName, templLineNo, t ))
 
     te_pm_state fsm_state  = PM_ST_INIT;
     ag_bool     line_start = AG_TRUE;  /* set TRUE first time only */
@@ -413,12 +413,13 @@ loadPseudoMacro( tCC* pzData, tCC* pzFileName )
      *  if it has been changed.
      */
     if (serverArgs[0] != NULL) {
-        char* pz = getenv( "SHELL" );
+        char* pz = getenv( zShellEnv );
         if ((pz != NULL) && (strcmp( pz, serverArgs[0] ) != 0)) {
             fprintf( pfTrace, "Changing server shell from %s to %s\n",
                      serverArgs[0], pz );
             closeServer();
             serverArgs[0] = pz;
+            pzShellProgram = pz;
         }
     }
 
