@@ -1,6 +1,6 @@
 /* -*- buffer-read-only: t -*- vi: set ro:
  *
- * AutoGen Globally exported prototypes Sun Oct 13 12:22:46 PDT 2002
+ * AutoGen Globally exported prototypes Sun Feb 16 12:05:33 PST 2003
  */
 #ifndef AUTOGEN_PROTOTYPES_H
 #define AUTOGEN_PROTOTYPES_H
@@ -29,6 +29,8 @@ runShell( const char*  pzCmd );
 
 /* exports from agUtils.c */
 
+char*
+aprf( const char* pzFmt, ... );
 void
 doOptions( int arg_ct, char** arg_vec );
 tCC*
@@ -77,30 +79,28 @@ readDefines( void );
 
 /* exports from defReduce.c */
 
+void
+freeEntry( tDefEntry* pDE );
+tDefEntry*
+getEntry( void );
 YYSTYPE
-addSibMacro(
-        YYSTYPE  def,
-        YYSTYPE  list );
+addSibMacro( YYSTYPE def, YYSTYPE  list );
 YYSTYPE
 makeMacro(
-        YYSTYPE    place,
-        YYSTYPE    val,
-        teValType  type );
+    YYSTYPE    place,
+    YYSTYPE    val,
+    teValType  type );
 YYSTYPE
 makeMacroList(
-        YYSTYPE    place,
-        YYSTYPE    list,
-        teValType  type );
+    YYSTYPE    place,
+    YYSTYPE    list,
+    teValType  type );
 YYSTYPE
 startList( YYSTYPE entry );
 YYSTYPE
-appendList(
-        YYSTYPE entry,
-        YYSTYPE list );
+appendList( YYSTYPE entry, YYSTYPE list );
 YYSTYPE
-findPlace(
-        YYSTYPE name,
-        YYSTYPE index );
+findPlace( YYSTYPE name, YYSTYPE index );
 YYSTYPE
 makeEmptyDefs( void );
 YYSTYPE
