@@ -2,13 +2,13 @@
 /*
  *  tpParse.c
  *
- *  $Id: tpParse.c,v 3.6 2002/03/27 04:45:29 bkorb Exp $
+ *  $Id: tpParse.c,v 1.19 2003/02/15 22:58:59 bkorb Exp $
  *
  *  This module will load a template and return a template structure.
  */
 
 /*
- *  AutoGen copyright 1992-2002 Bruce Korb
+ *  AutoGen copyright 1992-2003 Bruce Korb
  *
  *  AutoGen is free software.
  *  You may redistribute it and/or modify it under the terms of the
@@ -110,7 +110,7 @@ whichFunc( tCC** ppzScan )
         char* pzCopy = pCurTemplate->pNext;
         while (ISNAMECHAR( *pzFuncName ))
             *(pzCopy++) = *(pzFuncName++);
-        *(pzCopy++) = '\0';
+        *(pzCopy++) = NUL;
         *ppzScan = pzFuncName;
         pCurTemplate->pNext = pzCopy;
     }
@@ -147,17 +147,17 @@ findMacroEnd( tCC** ppzMark )
     *ppzMark     = pzMark;
 
     pzEndMark = strstr( pzMark, zEndMac );
-	if (pzEndMark == NULL)
-		AG_ABEND( "macro has no end" );
+    if (pzEndMark == NULL)
+        AG_ABEND( "macro has no end" );
 
-	pzNextMark = strstr( pzMark, zStartMac );
-	if (pzNextMark == NULL)
-		return pzEndMark;
+    pzNextMark = strstr( pzMark, zStartMac );
+    if (pzNextMark == NULL)
+        return pzEndMark;
 
-	if (pzEndMark > pzNextMark)
-		AG_ABEND( "macros cannot nest" );
+    if (pzEndMark > pzNextMark)
+        AG_ABEND( "macros cannot nest" );
 
-	return pzEndMark;
+    return pzEndMark;
 }
 
 
@@ -221,7 +221,7 @@ parseTemplate( tMacro* pM, tCC** ppzText )
                 if ((*(pzCopy++) = *(pzScan++)) == '\n')
                     templLineNo++;
             } while (pzScan < pzEnd);
-            *(pzCopy++) = '\0';
+            *(pzCopy++) = NUL;
             pM++;
             pT->pNext = pzCopy;
         }
@@ -260,7 +260,7 @@ parseTemplate( tMacro* pM, tCC** ppzText )
             while ((pzMark < pzMacEnd) && isspace( *pzMark ))  pzMark++;
             while ((pzMacEnd > pzMark) && isspace( pzMacEnd[-1] )) pzMacEnd--;
             if (pzMark != pzMacEnd) {
-                pM->ozText = (off_t)pzMark;
+                pM->ozText = (uintptr_t)pzMark;
                 pM->res    = (long)(pzMacEnd - pzMark);
             }
         }
