@@ -1,6 +1,6 @@
 
 /*
- *  $Id: enumeration.c,v 2.11 2002/09/21 19:35:40 bkorb Exp $
+ *  $Id: enumeration.c,v 2.14 2003/02/15 22:58:59 bkorb Exp $
  *
  *   Automated Options Paged Usage module.
  *
@@ -9,7 +9,7 @@
  */
 
 /*
- *  Automated Options copyright 1992-2002 Bruce Korb
+ *  Automated Options copyright 1992-2003 Bruce Korb
  *
  *  Automated Options is free software.
  *  You may redistribute it and/or modify it under the terms of the
@@ -63,9 +63,10 @@ enumError( pOpts, pOD, paz_names, name_ct )
     int       name_ct;
 {
     if (pOpts != NULL)
-        fprintf( stderr, pz_fmt, pOpts->pzProgName, pOD->pzLastArg );
+        fprintf( option_usage_fp, pz_fmt, pOpts->pzProgName, pOD->pzLastArg );
 
-    fprintf( stderr, "The valid %s option keywords are:\n", pOD->pz_Name );
+    fprintf( option_usage_fp, "The valid %s option keywords are:\n",
+             pOD->pz_Name );
 
     if (**paz_names == 0x7F) {
         paz_names++;
@@ -73,7 +74,7 @@ enumError( pOpts, pOD, paz_names, name_ct )
     }
 
     do  {
-        fprintf( stderr, "\t%s\n", *(paz_names++) );
+        fprintf( option_usage_fp, "\t%s\n", *(paz_names++) );
     } while (--name_ct > 0);
 
     if (pOpts != NULL)
@@ -133,7 +134,7 @@ optionEnumerationVal( pOpts, pOD, paz_names, name_ct )
         /*
          *  Replace the enumeration value with the name string.
          */
-        return paz_names[ (int)(pOD->pzLastArg) ];
+        return (char*)paz_names[ (int)(pOD->pzLastArg) ];
 
     default:
         break;
@@ -151,6 +152,7 @@ optionEnumerationVal( pOpts, pOD, paz_names, name_ct )
                 return (char*)idx;
             if (res != -1) {
                 pz_fmt = "%s error:  the keyword `%s' is ambiguous\n";
+                option_usage_fp = stderr;
                 enumError( pOpts, pOD, paz_names, name_ct );
             }
             res = idx;
@@ -159,6 +161,7 @@ optionEnumerationVal( pOpts, pOD, paz_names, name_ct )
 
     if (res < 0) {
         pz_fmt = "%s error:  `%s' does not match any keywords\n";
+        option_usage_fp = stderr;
         enumError( pOpts, pOD, paz_names, name_ct );
     }
 
@@ -174,4 +177,4 @@ optionEnumerationVal( pOpts, pOD, paz_names, name_ct )
  * c-file-style: "stroustrup"
  * indent-tabs-mode: nil
  * End:
- * pgusage.c ends here */
+ * enumeration.c ends here */
