@@ -1,6 +1,6 @@
 
 /*
- *  $Id: numeric.c,v 3.1 2002/03/29 02:22:17 bkorb Exp $
+ *  $Id: numeric.c,v 2.8 2003/02/15 22:58:59 bkorb Exp $
  *
  *   Automated Options Paged Usage module.
  *
@@ -9,7 +9,7 @@
  */
 
 /*
- *  Automated Options copyright 1992-2002 Bruce Korb
+ *  Automated Options copyright 1992-2003 Bruce Korb
  *
  *  Automated Options is free software.
  *  You may redistribute it and/or modify it under the terms of the
@@ -51,11 +51,6 @@
  * If you do not wish that, delete this exception notice.
  */
 
-#include <stdio.h>
-#include <stdlib.h>
-#include <unistd.h>
-#include <memory.h>
-
 #include "autoopts.h"
 
 /*
