@@ -1,6 +1,6 @@
 
 /*
- *  $Id: pgusage.c,v 3.1 2002/03/29 02:22:17 bkorb Exp $
+ *  $Id: pgusage.c,v 2.13 2003/02/15 22:58:59 bkorb Exp $
  *
  *   Automated Options Paged Usage module.
  *
@@ -9,7 +9,7 @@
  */
 
 /*
- *  Automated Options copyright 1992-2002 Bruce Korb
+ *  Automated Options copyright 1992-2003 Bruce Korb
  *
  *  Automated Options is free software.
  *  You may redistribute it and/or modify it under the terms of the
@@ -51,12 +51,8 @@
  * If you do not wish that, delete this exception notice.
  */
 
-#include <stdio.h>
-#include <stdlib.h>
-#include <unistd.h>
-#include <memory.h>
-
 #include "autoopts.h"
+
 tePagerState pagerState = PAGER_STATE_INITIAL;
 
 /*
@@ -80,13 +76,18 @@ doPagedUsage( pOptions, pOD )
     case PAGER_STATE_INITIAL:
     {
         my_pid  = getpid();
+#ifdef HAVE_SNPRINTF
         snprintf( zPageUsage, sizeof(zPageUsage), "/tmp/use.%lu", (tUL)my_pid );
+#else
+        sprintf( zPageUsage, "/tmp/use.%lu", (tUL)my_pid );
+#endif
         unlink( zPageUsage );
 
         /*
-         *  Set stderr to this temporary file
+         *  Set usage output to this temporary file
          */
-        if (freopen( zPageUsage, "w" FOPEN_BINARY_FLAG, stderr ) != stderr)
+        option_usage_fp = fopen( zPageUsage, "w" FOPEN_BINARY_FLAG );
+        if (option_usage_fp == NULL)
             _exit( EXIT_FAILURE );
 
         pagerState = PAGER_STATE_READY;
@@ -119,9 +120,14 @@ doPagedUsage( pOptions, pOD )
         /*
          *  Page the file and remove it when done.
          */
+#ifdef HAVE_SNPRINTF
         snprintf( zPageUsage, sizeof(zPageUsage),
                   "%s /tmp/use.%lu ; rm -f /tmp/use.%2$lu",
                   pzPager, (tUL)my_pid );
+#else
+        sprintf( zPageUsage, "%s /tmp/use.%lu ; rm -f /tmp/use.%2$lu",
+                  pzPager, (tUL)my_pid );
+#endif
         fclose( stderr );
         dup2( STDOUT_FILENO, STDERR_FILENO );
 
@@ -130,8 +136,7 @@ doPagedUsage( pOptions, pOD )
 
     case PAGER_STATE_CHILD:
         /*
-         *  This is a child process.  We are not ready to
-         *  run the pager program yet.
+         *  This is a child process used in creating shell script usage.
          */
         break;
     }
