@@ -1,6 +1,6 @@
 
 /*
- *  $Id: putshell.c,v 2.9 2002/07/22 04:41:50 bkorb Exp $
+ *  $Id: putshell.c,v 2.12 2003/02/15 22:58:59 bkorb Exp $
  *
  *  This module will interpret the options set in the tOptions
  *  structure and print them to standard out in a fashion that
@@ -8,7 +8,7 @@
  */
 
 /*
- *  Automated Options copyright 1992-2002 Bruce Korb
+ *  Automated Options copyright 1992-2003 Bruce Korb
  *
  *  Automated Options is free software.
  *  You may redistribute it and/or modify it under the terms of the
@@ -50,9 +50,6 @@
  * If you do not wish that, delete this exception notice.
  */
 
-#include <stdio.h>
-#include <string.h>
-
 #ifdef __STDC__
 #include "autoopts.h"
 
@@ -217,7 +214,7 @@ putBourneShell( tOptions* pOpts )
 }
 #else
 int putBourneShell( pOpts )
-    tOptions* pOpts;
+    char* pOpts;
 {
     fputs( "putBourneShell disabled for pre-ANSI C\n", stderr );
     exit( EXIT_FAILURE );
